@@ -35,9 +35,13 @@ class Tag(SubDir):
     def creation_date(cls, t):
         stamp = t.path() / ".stamp"
         if stamp.is_file():
-            return stamp.stat().st_ctime
+            # prefer mtime over ctime
+            # on UNIX, ctime is "the time of most recent metadata change" whereas
+            # mtime is "most recent content modification"
+            return stamp.stat().st_mtime
         return 0
 
+    @property
     def timestamp(self) -> int:
         return Tag.creation_date(self)
 
